"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Providers = void 0;
const wallet_adapter_react_ui_1 = require("@solana/wallet-adapter-react-ui");
const react_1 = require("@strata-foundation/react");
const react_2 = __importDefault(require("react"));
const react_hot_toast_1 = __importDefault(require("react-hot-toast"));
const MarketplaceProviders_1 = require("./MarketplaceProviders");
const Wallet_1 = require("./Wallet");
const Providers = ({ children, cluster, }) => {
    const onError = react_2.default.useCallback((error) => {
        var _a, _b;
        console.error(error);
        if ((_a = error.message) === null || _a === void 0 ? void 0 : _a.includes("Attempt to debit an account but found no record of a prior credit.")) {
            error = new Error("Not enough SOL to perform this action");
        }
        const code = (((_b = error.message) === null || _b === void 0 ? void 0 : _b.match("custom program error: (.*)")) ||
            [])[1];
        if (code == "0x1") {
            error = new Error("Insufficient balance.");
        }
        else if (code === "0x0") {
            error = new Error("Blockhash expired. Please retry");
        }
        react_hot_toast_1.default.custom((t) => (react_2.default.createElement(react_1.Notification, { type: "error", show: t.visible, heading: error.name, 
            // @ts-ignore
            message: error.message || error.msg || error.toString(), onDismiss: () => react_hot_toast_1.default.dismiss(t.id) })));
    }, [react_hot_toast_1.default]);
    return (react_2.default.createElement(Wallet_1.Wallet, { cluster: cluster },
        react_2.default.createElement(wallet_adapter_react_ui_1.WalletModalProvider, null,
            react_2.default.createElement(MarketplaceProviders_1.MarketplaceProviders, { onError: onError, resetCSS: true }, children))));
};
exports.Providers = Providers;
//# sourceMappingURL=Providers.js.map